# MLPro-MPPS - A Customizable Multi-Purpose Production Systems in Python

<img src="https://github.com/fhswf/MLPro/blob/main/doc/logo/original/logo.png?raw=True" align="right" width="25%"/>
MLPro-MPPS provides functionalities to design and develop customizable multi-purpose production systems in Python. This framework is integrated with MLPro (https://mlpro.readthedocs.io) and inherits several basic functionalities from MLPro. The user can design a simulation of a production system from the lowest component level (sensors and actuators) until the combination of them in form of MPPS. The other possibility is to use the ready-to-use components in the pool of objects. Moreover, since MLPro-MPPS is compatible with MLPro, it is possible to utilize MLPro-MPPS as an environment in MLPro-RL, as a game board in MLPro-GT, or as a state transition function in a MLPro-BF-Systems. Hence, MLPro-MPPS is reusable and powerful.

## Getting Started
To get started with MLPro-MPPS, you can begin with the following tasks:

### Installation from PyPI
............ (Available soon)

### Installation from Anaconda
............ (Available soon)

### Dependencies
Please read [requirements.txt](https://github.com/fhswf/MLPro-MPPS/blob/main/requirements.txt)

### First Steps
After installing MLPro-MPPS and its dependencies, we suggest starting with the ready-to-run examples:
1. [HOWTO 001 - SETTING UP COMPONENTS AND MODULES](https://github.com/fhswf/MLPro-MPPS/blob/main/src/mlpro_mpps/examples/howto_001_set_up_components_and_modules_in_MPPS.py)
2. [HOWTO 002 - SETTING UP MPPS](https://github.com/fhswf/MLPro-MPPS/blob/main/src/mlpro_mpps/examples/howto_002_set_up_MPPS.py)
3. [HOWTO 003 - MPPS IN REINFORCEMENT LEARNING](https://github.com/fhswf/MLPro-MPPS/blob/main/src/mlpro_mpps/examples/howto_003_run_RL_on_BGLP_using_MPPS.py)
4. [HOWTO 004 - MPPS IN GAME THEORY](https://github.com/fhswf/MLPro-MPPS/blob/main/src/mlpro_mpps/examples/howto_004_run_GT_on_BGLP_using_MPPS.py)

Additionally, the class diagram of the basic function is available in [this directory](https://github.com/fhswf/MLPro-MPPS/tree/main/doc/class_diagram). The ready-to-use components and MPPS samples can be found in [this directory](https://github.com/fhswf/MLPro-MPPS/tree/main/src/mlpro_mpps/pool).


## Key Features and Functionalities
What are the elements?
How to setup components and MPPS?
Integrations to MLPro? (MPPS as RL env, GT game board, etc.)
............

## Development
- Consequent object-oriented design and programming (OOD/OOP)
- Quality assurance by test-driven development
- Hosted and managed on GitHub
- Agile CI/CD approach with automated test and deployment
- Clean code paradigma

## Citing MLPro-MPPS
......


## Project and Team
Project MLPro-MPPS was started in 2022 by the [Group for Automation Technology and Learning Systems at the South Westphalia University of Applied Sciences, Germany](https://www.fh-swf.de/de/forschung___transfer_4/labore_3/labs/labor_fuer_automatisierungstechnik__soest_1/standardseite_57.php).

MLPro is currently designed and developed by [Steve Yuwono](https://github.com/steveyuwono), [Marlon Löppenberg](https://github.com/marlonloeppenberg), [Detlef Arend](https://github.com/detlefarend) and further [contributors](https://github.com/fhswf/MLPro/graphs/contributors). 


## How to contribute
If you want to contribute, please read [CONTRIBUTING.md](https://github.com/fhswf/MLPro-MPPS/blob/main/CONTRIBUTING.md)
